@@ -42,6 +42,13 @@ class Main():
         SysConfig = Config()
         return SysConfig.getMarkdownImgDirPath()+'\\'+copyFileName
 
+    def isImgFileName(self, file):
+        imgExts = ('.png','.gif','.jpg','.jpeg','.svg','.bmp')
+        for imgExt in imgExts:
+            if file.endswith(imgExt):
+                return True
+        return False
+
     def findLocalImageFile(self, line: str, localImages: set):
         '''递归查找某段字符串中中括号包裹的内容是否为本地图片'''
         linePart = line.partition('(')
@@ -49,8 +56,7 @@ class Main():
             secondPart = linePart[2].partition(')')
             content = secondPart[0]
             if len(content) > 0:
-                # print(content)
-                if content.endswith('.png') and os.path.exists(content):
+                if self.isImgFileName(content) and os.path.exists(content):
                     localImages.add(content)
                     self.findLocalImageFile(content, localImages)
 
@@ -61,8 +67,7 @@ class Main():
             secondPart = linePart[2].partition(')')
             content = secondPart[0]
             if len(content) > 0:
-                # print(content)
-                if content.endswith('.png'):
+                if self.isImgFileName(content):
                     localImages.append(content)
                     self.findImagesInStr(content, localImages)
 
