@@ -22,9 +22,6 @@ class SmmsImg():
             return res['images']
         else:
             pass
-        # logOpen = open(file='upload.log', mode='a')
-        # print(res, file=logOpen)
-        # logOpen.close()
         self.sysConfig.writeErrorLog(str(res))
         return False
 
@@ -64,18 +61,48 @@ class SmmsImg():
             return urls['ali']
         return urls['rruu']
 
+    def uploadToYujian(self, imgPath):
+        '''上传到遇见图床和阿里图床'''
+        imgOpen = open(imgPath, 'rb')
+        files = {'image': imgOpen}
+        apiType = 'ali'
+        token = self.sysConfig.getYujianToken()
+        r = requests.post('https://www.hualigs.cn/api/upload',
+                          data={'apiType': apiType, 'privateStorage': '', 'token': token}, files=files)
+        imgOpen.close()
+        try:
+            respJson = r.json()
+        except json.decoder.JSONDecodeError as e:
+            self.sysConfig.writeErrorLog("接口解析错误："+str(e)+"\n返回信息："+r.text)
+            raise UserException(UserException.CODE_UPLOAD_ERROR)
+        except Exception as e:
+            self.sysConfig.writeErrorLog("未知的接口调用错误:"+str(e))
+            raise UserException(UserException.CODE_UPLOAD_ERROR)
+        urls = {}
+        if str(respJson['code']).strip() == '200' and str(respJson['msg']).strip() == 'success':
+            urls['yujian'] = respJson['data']['url']['distribute']
+            urls['ali'] = respJson['data']['url']['ali']
+        else:
+            return False
+        if self.sysConfig.getConfigParam(Config.PARAM_IMG_SERVICE) == Config.IMG_SERVICE_ALI:
+            return urls['ali']
+        return urls['yujian']
+
     def multiUploadImage(self, images: list, results: dict):
         '''批量上传图片'''
         if len(images) <= 10:
             for localImg in images:
-                imgService = self.sysConfig.getConfigParam(Config.PARAM_IMG_SERVICE)
+                imgService = self.sysConfig.getConfigParam(
+                    Config.PARAM_IMG_SERVICE)
                 webImage = ''
                 if imgService == Config.IMG_SERVICE_ALI:
-                    webImage = self.uploadToRruu(localImg)
+                    webImage = self.uploadToYujian(localImg)
                 elif imgService == Config.IMG_SERVICE_RRUU:
                     webImage = self.uploadToRruu(localImg)
                 elif imgService == Config.IMG_SERVICE_VIMCN:
                     webImage = self.uploadToVimCn(localImg)
+                elif imgService == Config.IMG_SERVICE_YUJIAN:
+                    webImage = self.uploadToYujian(localImg)
                 else:
                     webImage = self.uploadToSmms(localImg)
                 if webImage == False:
